==> openGion6.9.5.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2018/03/29 14:26:08                                            */
/****************************************************************************/

CREATE TABLE GE30 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID           */
 , PTN_ID       VARCHAR2 (   20 )                   NOT NULL            /*  20 定型文ID         */
 , FROM_ID      VARCHAR2 (   50 )                   NOT NULL            /*  30 送信者ID         */
 , TO_ID        VARCHAR2 ( 4000 )                                       /*  40 宛先(TO)         */
 , CC_ID        VARCHAR2 ( 4000 )                                       /*  50 宛先(CC)         */
 , BCC_ID       VARCHAR2 ( 4000 )                                       /*  60 宛先(BCC)        */
 , H_TXT        VARCHAR2 ( 1000 )                                       /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        VARCHAR2 ( 1000 )                                       /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    VARCHAR2 (  300 )                                       /*  90 画面URL(暗号化)  */
 , PARAM0       VARCHAR2 ( 4000 )                                       /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       VARCHAR2 ( 4000 )                                       /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       VARCHAR2 ( 1000 )                                       /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       VARCHAR2 ( 1000 )                                       /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       VARCHAR2 ( 1000 )                                       /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       VARCHAR2 ( 1000 )                                       /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       VARCHAR2 ( 1000 )                                       /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       VARCHAR2 ( 1000 )                                       /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       VARCHAR2 ( 1000 )                                       /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       VARCHAR2 ( 1000 )                                       /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      VARCHAR2 (  256 )                                       /* 200 添付1            */
 , ATTACH2      VARCHAR2 (  256 )                                       /* 210 添付2            */
 , ATTACH3      VARCHAR2 (  256 )                                       /* 220 添付3            */
 , ATTACH4      VARCHAR2 (  256 )                                       /* 230 添付4            */
 , ATTACH5      VARCHAR2 (  256 )                                       /* 240 添付5            */
 , SNDTIME      VARCHAR2 (   14 )                                       /* 250 送信日次         */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時         */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG           */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG         */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成社員         */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時         */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG           */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG         */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者           */
)
TABLESPACE GETBL01;


CREATE SEQUENCE GE30S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE30T00 
  BEFORE INSERT ON GE30
  FOR EACH ROW 
  BEGIN 
    SELECT GE30S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.2.8.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE30S.sql <==
/****************************************************************************/
/* GE30 ( ﾊﾟﾗﾒｰﾀﾃｰﾌﾞﾙ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE30 (
   SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID           */
 , PTN_ID       VARCHAR2 (   20 )                   NOT NULL            /*  20 定型文ID         */
 , FROM_ID      VARCHAR2 (   50 )                   NOT NULL            /*  30 送信者ID         */
 , TO_ID        VARCHAR2 ( 4000 )                                       /*  40 宛先(TO)         */
 , CC_ID        VARCHAR2 ( 4000 )                                       /*  50 宛先(CC)         */
 , BCC_ID       VARCHAR2 ( 4000 )                                       /*  60 宛先(BCC)        */
 , H_TXT        VARCHAR2 ( 1000 )                                       /*  70 ﾍｯﾀﾞｰ自由文      */
 , F_TXT        VARCHAR2 ( 1000 )                                       /*  80 ﾌｯﾀｰ自由文       */
 , GAMEN_URL    VARCHAR2 (  300 )                                       /*  90 画面URL(暗号化)  */
 , PARAM0       VARCHAR2 ( 4000 )                                       /* 100 ﾊﾟﾗﾒｰﾀ0          */
 , PARAM1       VARCHAR2 ( 4000 )                                       /* 110 ﾊﾟﾗﾒｰﾀ1          */
 , PARAM2       VARCHAR2 ( 1000 )                                       /* 120 ﾊﾟﾗﾒｰﾀ2          */
 , PARAM3       VARCHAR2 ( 1000 )                                       /* 130 ﾊﾟﾗﾒｰﾀ3          */
 , PARAM4       VARCHAR2 ( 1000 )                                       /* 140 ﾊﾟﾗﾒｰﾀ4          */
 , PARAM5       VARCHAR2 ( 1000 )                                       /* 150 ﾊﾟﾗﾒｰﾀ5          */
 , PARAM6       VARCHAR2 ( 1000 )                                       /* 160 ﾊﾟﾗﾒｰﾀ6          */
 , PARAM7       VARCHAR2 ( 1000 )                                       /* 170 ﾊﾟﾗﾒｰﾀ7          */
 , PARAM8       VARCHAR2 ( 1000 )                                       /* 180 ﾊﾟﾗﾒｰﾀ8          */
 , PARAM9       VARCHAR2 ( 1000 )                                       /* 190 ﾊﾟﾗﾒｰﾀ9          */
 , ATTACH1      VARCHAR2 (  256 )                                       /* 200 添付1            */
 , ATTACH2      VARCHAR2 (  256 )                                       /* 210 添付2            */
 , ATTACH3      VARCHAR2 (  256 )                                       /* 220 添付3            */
 , ATTACH4      VARCHAR2 (  256 )                                       /* 230 添付4            */
 , ATTACH5      VARCHAR2 (  256 )                                       /* 240 添付5            */
 , SNDTIME      VARCHAR2 (   14 )                                       /* 250 送信日時         */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時         */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG           */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG         */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者           */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時         */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG           */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG         */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者           */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE30S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE30T00 
  BEFORE INSERT ON GE30
  FOR EACH ROW 
  BEGIN 
    SELECT GE30S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
